import dayjs from 'dayjs'
import type { BasicFormItem } from '@/types/form'
import { useFormDesignerStore } from '@/stores/designer'

export const formatDate = (date: any, format = 'YYYY-MM-DD HH:mm') => {
  return dayjs(date).format(format)
}

export const isAbsolutePath = (path: string) => {
  return path.startsWith('http')
}


export const uuid = (len = 16) => {
  const chars = '0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz'.split('')
  const uuid = []

  if (len) {
    // 如果指定uuid长度,只是取随机的字符,0|x为位运算,能去掉x的小数位,返回整数位
    for (let i = 0; i < len; i++) uuid[i] = chars[0 | (Math.random() * chars.length)]
  } else {
    let r
    // rfc4122标准要求返回的uuid中,某些位为固定的字符
    uuid[8] = uuid[13] = uuid[18] = uuid[23] = '-'
    uuid[14] = '4'

    for (let i = 0; i < 36; i++) {
      if (!uuid[i]) {
        r = 0 | (Math.random() * 16)
        uuid[i] = chars[i == 19 ? (r & 0x3) | 0x8 : r]
      }
    }
  }

  return uuid.join('')
}

export const compToFormItem = (comp: any) => {
  const id = uuid(8)
  const formDesignerStore = useFormDesignerStore()
  console.log("comp",comp);
  
  const formItem: BasicFormItem = {
    id,
    label: comp.name,
    value: '',
    name: comp.type + '_' + id,
    type: comp.type,
    children: [],
    options: [],
    search: false,
    list: true,
    required: false,
    rules: [],
    props: comp.props || {},
    span: formDesignerStore.formSpan,
    slots: comp.slots,
    request:comp.request
  }
  if (['editor'].includes(comp.type)) {
    formItem.span = 24
  }
  return formItem
}

export const copyFormItem = (formItem: BasicFormItem) => {
  const id = uuid(8)
  return {
    ...JSON.parse(JSON.stringify(formItem)),
    id,
    name: formItem.type + '_' + id
  }
}

export const placeholder = (item: BasicFormItem) => {
  if (['select', 'cascader', 'date-picker', 'time-picker', 'time-select', 'dict'].includes(item.type)) {
    return '请选择' + item.label
  } else {
    return '请输入' + item.label
  }
}